#
# spec file for package python-psygnal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-psygnal
Version:        0.11.1
Release:        1.3
Summary:        Fast python callback/event system modeled after Qt Signals
License:        BSD-3-Clause
URL:            https://github.com/pyapp-kit/psygnal
Source:         https://files.pythonhosted.org/packages/source/p/psygnal/psygnal-%{version}.tar.gz
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling >= 1.8.0}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module mypy_extensions}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module msgspec}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pydantic}
BuildRequires:  %{python_module pytest >= 6.0}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module typing-extensions >= 3.7.4.2}
BuildRequires:  %{python_module wrapt}
# /SECTION
BuildRequires:  fdupes
Requires:       python-mypy_extensions
Requires:       python-typing-extensions >= 3.7.4.2
Suggests:       python-dask
Suggests:       python-ipython
Suggests:       python-numpy
Suggests:       python-pydantic
Suggests:       python-qtpy
Suggests:       python-rich
Suggests:       python-wrapt
Suggests:       python-griffe == 0.25.5
Suggests:       python-wrapt
BuildArch:      noarch
%python_subpackages

%description
Psygnal (pronounced "signal") is a pure python implementation of the [observer
pattern](https://en.wikipedia.org/wiki/Observer_pattern), with the API of
[Qt-style Signals](https://doc.qt.io/qt-5/signalsandslots.html) with (optional)
signature and type checking, and support for threading.

%prep
%autosetup -p1 -n psygnal-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/psygnal
%{python_sitelib}/psygnal-%{version}.dist-info

%changelog
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.1:
  * perf: let EventedSet use clear\(\) method of underlying set
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * refactor: change EmitLoopError message, and mechanism of info
    gathering \#302 (tlambert03)
  * feat: add signal aliases on SignalGroup \#299 (getzze)
  * feat!: Rename `recursion_mode` to `reemission`.  Rename
    `deferred` to `queued`.  Add `latest-only` mode.
    \(technically breaking\) \#296 (tlambert03)
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.2:
  * fix: fix hard reference to objects in emitted arguments \#301
  * feat: Add recursion\_mode \('immediate' or 'deferred'\) to
    Signal and SignalInstance \#293 (tlambert03)
  * feat: add collect\_fields option to SignalGroupDescriptor,
    and accept a SignalGroup subclass \#291 (getzze)
  * feat: support for evented containers as pydantic v2 fields
  * perf: Fixing performance of evented set \#275 (Czaki)
  * refactor!: New SignalGroup that does not subclass
    SignalInstance \#269 (tlambert03)
  * feat: emit the old value as second argument in Signals from
    SignalGroupDescriptor \(evented dataclass\) \#257 (getzze)
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.5:
  * feat: better repr for WeakCallback objects
  * refactor: make EmitLoop error message clearer
  * perf: don't compare before/after values in evented
    dataclass/model when no signals connected
  * fix: emission of events from root validators and extraneous
    emission of dependent fields
* Mon Sep  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 0.9.3.
